@@ -19,17 +19,22 @@ class Program:
 	def __init__(self, argv):
 		global queue
 		print(f'EasyCoder version {version("easycoder")}')
+		print(argv)
 		if len(argv) == 0:
 			print('No script supplied')
 			exit()
 		if argv in ['-v', '--version']: return
-		scriptName = argv
+		if argv[0:6] == 'debug ':
+			self.scriptName = argv[6:]
+			self.debugging = True
+		else:
+			self.scriptName = argv
+			self.debugging = False
 
-		f = open(scriptName, 'r')
+		f = open(self.scriptName, 'r')
 		source = f.read()
 		f.close()
 		queue = deque()
-		self.argv = argv
 		self.domains = []
 		self.domainIndex = {}
 		self.name = '<anon>'
@@ -47,16 +52,20 @@ class Program:
 		self.useClass(Core)
 		self.externalControl = False
 		self.ticker = 0
+		self.usingGraphics = False
+		self.debugger = None
 		self.running = True
 
 	# This is called at 10msec intervals by the GUI code
 	def flushCB(self):
 		self.ticker += 1
+		# if self.ticker % 1000 == 0: print(f'GUI Tick {self.ticker}')
 		flush()
 
 	def start(self, parent=None, module = None, exports=[]):
 		self.parent = parent
 		self.exports = exports
+		if self.debugging: self.useGraphics()
 		if module != None:
 			module['child'] = self
 		startCompile = time.time()
@@ -85,6 +94,16 @@ class Program:
 					time.sleep(0.01)
 				else:
 					break
+	
+	# Use the graphics module
+	def useGraphics(self):
+		if not self.usingGraphics:
+			print('Loading graphics module')
+			from .ec_pyside import Graphics
+			self.graphics = Graphics
+			self.useClass(Graphics)
+			self.usingGraphics = True
+		return True
 
 	# Import a plugin
 	def importPlugin(self, source):
@@ -147,8 +166,9 @@ class Program:
 			name = value['name']
 			symbolRecord = self.getSymbolRecord(name)
 			# if symbolRecord['hasValue']:
-			handler = self.domainIndex[symbolRecord['domain']].valueHandler('symbol')
-			result = handler(symbolRecord)
+			if symbolRecord:
+				handler = self.domainIndex[symbolRecord['domain']].valueHandler('symbol')
+				result = handler(symbolRecord)
 		# 	else:
 		# 		# Call the given domain to handle a value
 		# 		# domain = self.domainIndex[value['domain']]
@@ -181,7 +201,10 @@ class Program:
 		return None
 
 	def getValue(self, value):
-		return self.evaluate(value).content
+		result = self.evaluate(value)
+		if result:
+			return result.get('content')  # type: ignore[union-attr]
+		return None
 
 	def getRuntimeValue(self, value):
 		if value is None:
@@ -287,9 +310,9 @@ class Program:
 		return
 
 	def releaseParent(self):
-		if self.parent.waiting and self.parent.program.running:
-			self.parent.waiting = False
-			self.parent.program.run(self.parent.pc)
+		if self.parent and self.parent.waiting and self.parent.program.running:  # type: ignore[union-attr]
+			self.parent.waiting = False  # type: ignore[union-attr]
+			self.parent.program.run(self.parent.pc)  # type: ignore[union-attr]
 
 	# Flush the queue
 	def flush(self, pc):
@@ -297,6 +320,15 @@ class Program:
 		self.pc = pc
 		while self.running:
 			command = self.code[self.pc]
+			
+			# Check if debugger wants to halt before executing this command
+			if self.debugger != None:
+				# pc==1 is the first real command (pc==0 is the debug loader)
+				is_first = (self.pc == 1)
+				if self.debugger.checkIfHalt(is_first):
+					# Debugger says halt - break out and wait for user
+					break
+			
 			domainName = command['domain']
 			if domainName == None:
 				self.pc += 1
@@ -378,9 +410,9 @@ class Program:
 		if type(v2) == int:
 			if type(v1) != int:
 				v2 = f'{v2}'
-		if v1 > v2:
+		if v1 > v2:  # type: ignore[operator]
 			return 1
-		if v1 < v2:
+		if v1 < v2:  # type: ignore[operator]
 			return -1
 		return 0
 
@@ -395,8 +427,16 @@ class Program:
 
 # This is the program launcher
 def Main():
+	print(sys.argv)
 	if (len(sys.argv) > 1):
-		Program(sys.argv[1]).start()
+		# Check if 'debug' is the first argument
+		if sys.argv[1] == 'debug' and len(sys.argv) > 2:
+			# Create program with debug flag
+			program = Program(sys.argv[2])
+			program.debugging = True
+			program.start()
+		else:
+			Program(sys.argv[1]).start()
 	else:
 		Program('-v')
 
